@@ -165,7 +165,7 @@ ciTestDbs <- c("duckdb", "postgres", "redshift", "sqlserver", "snowflake")
 if (Sys.getenv("CI_TEST_DB") == "") {
 
   dbToTest <- c(
-    "duckdb"
+     "duckdb"
     # ,
     # "postgres"
     # ,
@@ -186,19 +186,23 @@ if (Sys.getenv("CI_TEST_DB") == "") {
 
 
 # make sure we're only trying to test on dbs we have connection details for
-if("postgres" %in% dbToTest & Sys.getenv("CDM5_POSTGRESQL_SERVER") == ""){
+if ("postgres" %in% dbToTest & Sys.getenv("CDM5_POSTGRESQL_SERVER") == "") {
   dbToTest <- dbToTest[dbToTest != "postgres"]
-  print(paste("CI tests not run on postgres - CDM5_POSTGRESQL_SERVER not found"))
+  print("CI tests not run on postgres - CDM5_POSTGRESQL_SERVER not found")
 }
-if("redshift" %in% dbToTest & Sys.getenv("CDM5_REDSHIFT_DBNAME") == ""){
+if ("redshift" %in% dbToTest & Sys.getenv("CDM5_REDSHIFT_DBNAME") == "") {
   dbToTest <- dbToTest[dbToTest != "redshift"]
-  print(paste("CI tests not run on redshift - CDM5_REDSHIFT_DBNAME not found"))
+  print("CI tests not run on redshift - CDM5_REDSHIFT_DBNAME not found")
 }
-if("sqlserver" %in% dbToTest & Sys.getenv("CDM5_SQL_SERVER_USER") == ""){
+if ("sqlserver" %in% dbToTest & Sys.getenv("CDM5_SQL_SERVER_USER") == "") {
   dbToTest <- dbToTest[dbToTest != "sqlserver"]
-  print(paste("CI tests not run on sqlserver - CDM5_SQL_SERVER_USER not found"))
+  print("CI tests not run on sqlserver - CDM5_SQL_SERVER_USER not found")
 }
-if("snowflake" %in% dbToTest & Sys.getenv("SNOWFLAKE_USER") == ""){
+if ("snowflake" %in% dbToTest & Sys.getenv("SNOWFLAKE_USER") == "") {
   dbToTest <- dbToTest[dbToTest != "snowflake"]
-  print(paste("CI tests not run on snowflake - SNOWFLAKE_USER not found"))
+  print("CI tests not run on snowflake - SNOWFLAKE_USER not found")
+}
+if (!rlang::is_installed("duckdb")) {
+  dbToTest <- dbToTest[dbToTest != "duckdb"]
+  print("CI tests not run on snowflake - duckdb package is not installed")
 }
