@@ -14,7 +14,8 @@
 # dbtype = "oracle"
 for (dbtype in dbToTest) {
   test_that(glue::glue("{dbtype} - verify_write_access"), {
-    if (dbtype != "duckdb") skip_on_ci()
+    if (!(dbtype %in% ciTestDbs)) skip_on_ci()
+    if (dbtype != "duckdb") skip_on_cran() else skip_if_not_installed("duckdb")
     write_schema <- get_write_schema(dbtype)
     con <- get_connection(dbtype)
     skip_if(any(write_schema == "") || is.null(con))
