@@ -3,14 +3,16 @@ test_that("assertTables works with local cdms", {
   skip_if_not_installed('arrow')
   skip_if_not_installed("duckdb")
   skip_on_cran()
-  con <- DBI::dbConnect(duckdb::duckdb(), dbdir = eunomia_dir())
-  cdm <- cdm_from_con(con, cdm_schema = "main")
+  con <- DBI::dbConnect(duckdb::duckdb(eunomia_dir()))
+  cdm <- cdm_from_con(
+    con = con, cdm_name = "eunomia", cdm_schema = "main", write_schema = "main"
+  )
 
   expect_equal(version(cdm), "5.3")
   expect_error(assertTables(cdm, "concept"), NA)
 
   # local r
-  cdm_r <- collect(cdm)
+  cdm_r <- dplyr::collect(cdm)
   expect_equal(version(cdm_r), "5.3")
   assertTables(cdm_r, "concept")
 
